@@ -1,34 +1,39 @@
 import os
+from doreah.settings import get_settings
+from doreah.settings import config as settingsconfig
 
 
-# data folder
-# must be determined first because getting settings relies on it
 
-try:
-	DATA_DIR = os.environ["XDG_DATA_HOME"].split(":")[0]
-	assert os.path.exists(DATA_DIR)
-except:
-	DATA_DIR = os.path.join(os.environ["HOME"],".local/share/")
+# check environment variables for data directory
+# otherwise, go with defaults
+setting_datadir = get_settings("DATA_DIRECTORY",files=[],environ_prefix="MALOJA_")
+if setting_datadir is not None and os.path.exists(setting_datadir):
+	DATA_DIR = setting_datadir
+else:
+	try:
+		HOME_DIR = os.environ["XDG_DATA_HOME"].split(":")[0]
+		assert os.path.exists(HOME_DIR)
+	except:
+		HOME_DIR = os.path.join(os.environ["HOME"],".local/share/")
+
+	DATA_DIR = os.path.join(HOME_DIR,"maloja")
 
-DATA_DIR = os.path.join(DATA_DIR,"maloja")
 os.makedirs(DATA_DIR,exist_ok=True)
 
+
+
 def datadir(*args):
 	return os.path.join(DATA_DIR,*args)
 
 
 
+
+
 ### DOREAH CONFIGURATION
 
 from doreah import config
 
 config(
-	pyhp={
-		"version": 2
-	},
-	logging={
-		"logfolder": datadir("logs")
-	},
 	settings={
 		"files":[
 			datadir("settings/default.ini"),
@@ -41,12 +46,27 @@ config(
 	},
 	regular={
 		"autostart": False
+	},
+	auth={
+		"multiuser":False,
+		"cookieprefix":"maloja",
+		"stylesheets":["/style.css"],
+		"dbfile":datadir("auth/auth.ddb")
 	}
 )
 
+# because we loaded a doreah module already before setting the config, we need to to that manually
+settingsconfig._readpreconfig()
+
+config(
+	logging={
+		"logfolder": datadir("logs") if get_settings("LOGGING") else None
+	}
+)
+
+settingsconfig._readpreconfig()
 
 
-from doreah.settings import get_settings
 
 # thumbor
 
